﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinTree;

namespace UltraTreeWithCheckBoxColumns
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            SetupTree();
        }

        private void btnExit_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void SetupTree()
        {
            // Make the combobox drop down for the type of validation result
            ValueList valueList = new ValueList();
            valueList.ValueListItems.Add(1, "None");
            valueList.ValueListItems.Add(2, "Error");
            valueList.ValueListItems.Add(3, "Warning");
            valueList.ValueListItems.Add(4, "Information");

            // Set up the UltraCheckEditor so it looks good in a cell. 
            ultraCheckEditor1.Text = string.Empty;
            ultraCheckEditor1.CheckAlign = ContentAlignment.MiddleCenter;

            // Create a ColumnSet
            UltraTreeColumnSet columnSet = ultraTree.ColumnSettings.ColumnSets.Add("My Column Set");

            // Add columns to the ColumnSet. 
            UltraTreeNodeColumn column = columnSet.Columns.Add("Name");
            column.DataType = typeof(string);
            //column.LayoutInfo.PreferredCellSize = new Size(75, column.LayoutInfo.PreferredCellSize.Height);
            //column.PerformAutoResize(ColumnAutoSizeMode.AllNodesWithDescendants);

            column = columnSet.Columns.Add("Default");
            column.DataType = typeof(object);
            column.AllowCellEdit = AllowCellEdit.Default;
            column.EditorComponent = ultraCheckEditor1;

            column = columnSet.Columns.Add("ActivateOnly");
            column.DataType = typeof(object);
            column.AllowCellEdit = AllowCellEdit.ActivateOnly;
            column.EditorComponent = ultraCheckEditor1;

            column = columnSet.Columns.Add("Disabled");
            column.DataType = typeof(object);
            column.AllowCellEdit = AllowCellEdit.Disabled;
            column.EditorComponent = ultraCheckEditor1;

            column = columnSet.Columns.Add("Full");
            column.DataType = typeof(object);
            column.AllowCellEdit = AllowCellEdit.Full;
            column.EditorComponent = ultraCheckEditor1;

            column = columnSet.Columns.Add("ReadOnly");
            column.DataType = typeof(object);
            column.AllowCellEdit = AllowCellEdit.ReadOnly;
            column.EditorComponent = ultraCheckEditor1;

            column = columnSet.Columns.Add("ComboBox");
            column.AllowCellEdit = AllowCellEdit.Full;
            column.DataType = typeof(string);
            column.ValueList = valueList;

            // Assign this ColumnSet to every node in the tree. 
            ultraTree.Override.ColumnSet = columnSet;
            ultraTree.Override.ColumnSet.Columns["Name"].PerformAutoResize(ColumnAutoSizeMode.AllNodesWithDescendants);
            ultraTree.Override.CellClickAction = CellClickAction.EditCell;

            // Set the nodestyle to allow editing of the checkboxes
            ultraTree.Override.NodeStyle = NodeStyle.CheckBox;

            // Populate the tree with nodes
            UltraTreeNode nodeA = ultraTree.Nodes.Add("A");
            UltraTreeNode nodeB = ultraTree.Nodes.Add("B");
            nodeA.Cells["Name"].Value = nodeA.Key;
            nodeB.Cells["Name"].Value = nodeB.Key;

            foreach (var n in ultraTree.Nodes)
            {
                UltraTreeNode node1 = n.Nodes.Add(n.Key + " 1");
                UltraTreeNode node2 = n.Nodes.Add(n.Key + " 2");
                node1.Cells["Name"].Value = node1.Key;
                node2.Cells["Name"].Value = node2.Key;

                foreach (var m in n.Nodes)
                {
                    for (int i = 1; i < 5; i++)
                    {
                        UltraTreeNode leaf = m.Nodes.Add(m.Key + ": " + i + " leaf");
                        leaf.Cells["Name"].Value = leaf.Key;
                        leaf.Cells["Default"].Value = i % 2 == 0;
                        leaf.Cells["ActivateOnly"].Value = i % 3 == 0;
                        leaf.Cells["Disabled"].Value = i % 2 == 0;
                        leaf.Cells["Full"].Value = i % 3 == 0;
                        leaf.Cells["ReadOnly"].Value = i % 2 == 0;
                        leaf.Cells["ComboBox"].Value = i;
                    }
                }
            }
        }

        private void Form1_Load(object sender, EventArgs e)
        {

        }
    }
}
